!> \~japanese
!! \brief 物理定数をまとめたモジュール.
!! \~english
!! \brief This module collects the physical constants.
!! \~
!!
!! <br><br>
!! \b Copyright (C) GFD Dennou Club, 2011-2012. All rights reserved. <br>
!! \b license ?? <br>
!! \author Yuta Kawai
!!
module Universal_Constants
  ! モジュール引用 ; Use statements
  !
  
  ! 種類型パラメータ
  ! Kind type parameter
  !
  use dc_types, only: DP ! 倍精度実数型. Double precision.

  ! 宣言文 ; Declaration statements
  !
  implicit none
  private

  !> \~japanese 万有引力定数 \f$ \rm [ m^3 kg^{-1} s^{-2} ] \f$.
  !! \~english Gravitational constant \f$ \rm [ m^3 kg^{-1} s^{-2} ] \f$.
  real(DP), parameter :: univ_G = 6.67428e-11

  !> \~japanese 普遍気体定数 \f$ \rm [ J mol^{-1} K ] \f$.
  !! \~english The universal gas constant \f$ \rm [ J mol^{-1} K ] \f$.
  real(DP), parameter :: uni_R = 8.314472

end module Universal_Constants
